@@ -9,28 +9,28 @@
 # lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("3.3.") or
-    raise "ruby lib version (3.3.10) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("3.4.") or
+    raise "ruby lib version (3.4.4) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby3.3/3.3.0/x86_64-darwin14")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby3.4/3.4.0/x86_64-darwin14")
   # DESTDIR on make install.
   DESTDIR = '' unless defined? DESTDIR
   # The hash configurations stored.
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
-  CONFIG["MINOR"] = "3"
-  CONFIG["TEENY"] = "10"
-  CONFIG["PATCHLEVEL"] = "183"
+  CONFIG["MINOR"] = "4"
+  CONFIG["TEENY"] = "4"
+  CONFIG["PATCHLEVEL"] = "34"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/opt/local")
-  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)3.3"
-  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)3.3"
+  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)3.4"
+  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)3.4"
   CONFIG["RUBY_SO_NAME"] = "$(RUBY_BASE_NAME).$(RUBY_API_VERSION)"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-3.3.pc"
+  CONFIG["ruby_pc"] = "ruby-3.4.pc"
   CONFIG["CC_WRAPPER"] = ""
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
@@ -41,11 +41,11 @@ module RbConfig
   CONFIG["rubyarchhdrdir"] = "$(rubyhdrdir)/$(arch)"
   CONFIG["vendorhdrdir"] = "$(rubyhdrdir)/vendor_ruby"
   CONFIG["sitehdrdir"] = "$(rubyhdrdir)/site_ruby"
-  CONFIG["rubyhdrdir"] = "$(DESTDIR)/opt/local/include/ruby-3.3.10"
+  CONFIG["rubyhdrdir"] = "$(DESTDIR)/opt/local/include/ruby-3.4.4"
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--enable-install-static-library' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--disable-yjit' '--disable-rjit' '--without-gmp' '--enable-mkmf-verbose' '--with-opt-dir=/opt/local' '--program-suffix=3.3' '--with-rubyhdrdir=/opt/local/include/ruby-3.3.10' '--with-rubylibprefix=/opt/local/lib/ruby3.3' '--with-openssl-dir=/opt/local/libexec/openssl3' '--without-baseruby' 'AR=/opt/local/bin/ar' 'RANLIB=/opt/local/bin/ranlib' '--with-arch=x86_64' 'CC=/usr/bin/clang' 'CXX=/usr/bin/clang++' 'CFLAGS=-pipe -I/opt/local/libexec/openssl3/include -Os -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl3/lib -Wl,-headerpad_max_install_names -L/opt/local/lib -lMacportsLegacySupport -arch x86_64' 'CPPFLAGS=-isystem/opt/local/include/LegacySupport -I/opt/local/libexec/openssl3/include -isystem/opt/local/include' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl3/include -Os -stdlib=libc++ -arch x86_64'"
+  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--enable-install-static-library' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--disable-yjit' '--disable-rjit' '--without-gmp' '--enable-mkmf-verbose' '--with-opt-dir=/opt/local' '--program-suffix=3.4' '--with-rubyhdrdir=/opt/local/include/ruby-3.4.4' '--with-rubylibprefix=/opt/local/lib/ruby3.4' '--with-openssl-dir=/opt/local/libexec/openssl3' '--without-baseruby' 'AR=/opt/local/bin/ar' 'RANLIB=/opt/local/bin/ranlib' '--with-arch=x86_64' 'CC=/usr/bin/clang' 'CXX=/usr/bin/clang++' 'CFLAGS=-pipe -I/opt/local/libexec/openssl3/include -Os -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl3/lib -Wl,-headerpad_max_install_names -L/opt/local/lib -lMacportsLegacySupport -arch x86_64' 'CPPFLAGS=-isystem/opt/local/include/LegacySupport -I/opt/local/libexec/openssl3/include -isystem/opt/local/include' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl3/include -Os -stdlib=libc++ -arch x86_64'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -55,7 +55,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "3.3.0"
+  CONFIG["ruby_version"] = "3.4.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "x86_64-darwin14"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -97,6 +97,7 @@ module RbConfig
   CONFIG["rubyw_install_name"] = ""
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
+  CONFIG["hardenflags"] = "-fstack-protector-strong -U_FORTIFY_SOURCE -D_FORTIFY_SOURCE=2"
   CONFIG["strict_warnflags"] = ""
   CONFIG["warnflags"] = "-Wall -Wextra -Wextra-tokens -Wdeprecated-declarations -Wdivision-by-zero -Wdiv-by-zero -Wimplicit-function-declaration -Wimplicit-int -Wpointer-arith -Wshorten-64-to-32 -Wwrite-strings -Wold-style-definition -Wmissing-noreturn -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable -Wundef"
   CONFIG["debugflags"] = "-ggdb3"
@@ -112,6 +113,7 @@ module RbConfig
   CONFIG["CARGO"] = ""
   CONFIG["RUSTC"] = "no"
   CONFIG["INSTALL_STATIC_LIBRARY"] = "yes"
+  CONFIG["modular_gc_dir"] = ""
   CONFIG["EXECUTABLE_EXTS"] = ""
   CONFIG["ARCHFILE"] = ""
   CONFIG["LIBRUBY_RELATIVE"] = "no"
@@ -119,14 +121,14 @@ module RbConfig
   CONFIG["PREP"] = "miniruby$(EXEEXT)"
   CONFIG["CROSS_COMPILING"] = "no"
   CONFIG["TEST_RUNNABLE"] = "yes"
-  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby3.3"
+  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby3.4"
   CONFIG["setup"] = "Setup"
   CONFIG["SOEXT"] = "dylib"
   CONFIG["TRY_LINK"] = ""
   CONFIG["PRELOADENV"] = "DYLD_INSERT_LIBRARIES"
   CONFIG["LIBPATHENV"] = "DYLD_LIBRARY_PATH"
   CONFIG["RPATHFLAG"] = ""
-  CONFIG["LIBPATHFLAG"] = " -L%s"
+  CONFIG["LIBPATHFLAG"] = "-L%s"
   CONFIG["LINK_SO"] = "\n$(POSTLINK)"
   CONFIG["ADDITIONAL_DLDFLAGS"] = ""
   CONFIG["ENCSTATIC"] = ""
@@ -145,8 +147,8 @@ module RbConfig
   CONFIG["GREP"] = "/usr/bin/grep"
   CONFIG["dsymutil"] = "dsymutil"
   CONFIG["codesign"] = "codesign"
-  CONFIG["cleanlibs"] = "$(TARGET_SO).dSYM"
-  CONFIG["POSTLINK"] = "dsymutil $@ 2>/dev/null; { test -z '$(RUBY_CODESIGN)' || codesign -s '$(RUBY_CODESIGN)' -f $@; }"
+  CONFIG["cleanlibs"] = "$(TARGET_SO:=.dSYM)"
+  CONFIG["POSTLINK"] = "dsymutil $@ 2>/dev/null; { test -z '$(RUBY_CODESIGN)' || codesign -s '$(RUBY_CODESIGN)' $@; }"
   CONFIG["incflags"] = "-I/opt/local/include"
   CONFIG["WERRORFLAG"] = "-Werror"
   CONFIG["RUBY_DEVEL"] = ""
@@ -167,7 +169,6 @@ module RbConfig
   CONFIG["LN_S"] = "ln -s"
   CONFIG["DLLWRAP"] = ""
   CONFIG["WINDRES"] = ""
-  CONFIG["ASFLAGS"] = ""
   CONFIG["ARFLAGS"] = "rcu "
   CONFIG["try_header"] = ""
   CONFIG["CC_VERSION_MESSAGE"] = "Apple LLVM version 7.0.2 (clang-700.1.81)\nTarget: x86_64-apple-darwin14.5.0\nThread model: posix"
@@ -196,6 +197,7 @@ module RbConfig
   CONFIG["CC"] = "/usr/bin/clang"
   CONFIG["wasmoptflags"] = ""
   CONFIG["WASMOPT"] = ""
+  CONFIG["config_target"] = "x86_64-apple-darwin14.5.0"
   CONFIG["target_os"] = "darwin14"
   CONFIG["target_vendor"] = "apple"
   CONFIG["target_cpu"] = "x86_64"
@@ -217,7 +219,7 @@ module RbConfig
   CONFIG["GIT"] = "git"
   CONFIG["cxxflags"] = ""
   CONFIG["cppflags"] = ""
-  CONFIG["cflags"] = "$(optflags) $(debugflags) $(warnflags)"
+  CONFIG["cflags"] = "$(hardenflags)  $(optflags) $(debugflags) $(warnflags)"
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = "$(target_alias)"
@@ -247,7 +249,7 @@ module RbConfig
   CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
-  CONFIG["program_transform_name"] = "s&$$&3.3&;s&^&&"
+  CONFIG["program_transform_name"] = "s&$$&3.4&;s&^&&"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["PACKAGE_URL"] = ""
   CONFIG["PACKAGE_BUGREPORT"] = ""
